{% load i18n %}

<div class="form-group aa-forum-form-group text-right clearfix">
    <p class="text-muted">
        {% translate "Fields marked with an asterisk (*) are mandatory" %}
    </p>
</div>
